from autoreduce_frontend.instrument.views.variables import _combine_dicts


def test_combine_dicts_empty_current():
    """
    Test: The default is properly used as both "current" and "default"
    When: `current` is empty
    """
    default_test = {"test_var": 123}
    expected = {"test_var": {"current": 123, "default": 123}}
    assert _combine_dicts({}, default_test) == expected


def test_combine_dicts():
    """
    Test: combine dicts works as expected - returns a dict with current and default
    When: dicts with matching variables are passed in
    """
    current_test = {"test_var": 123}
    default_test = {"test_var": 654}
    expected = {"test_var": {"current": 123, "default": 654}}
    assert _combine_dicts(current_test, default_test) == expected


def test_combine_dicts_current_more_vars():
    """
    Test: Value is None when current variables has a variable that's not in the defaults
    When: the current_variables dict has a variable that is not matching
    """
    current_test = {"test_var": 123, "not_in_defaults": "test"}
    default_test = {"test_var": 123}
    expected = {"test_var": {"current": 123, "default": 123}, "not_in_defaults": {"current": "test", "default": None}}
    assert _combine_dicts(current_test, default_test) == expected



# pylint:skip-file
"""
Wrapper for the functionality for various installation and project setup commands
see:
    `python setup.py help`
for more details
"""
from setuptools import setup, find_packages
from glob import glob
import os

PACKAGE_NAME = "autoreduce_frontend"

data_locations = [f"{PACKAGE_NAME}/templates/", f"{PACKAGE_NAME}/static/"]

data_files = []

for loc in data_locations:
    data_files.extend([f.split(f"{PACKAGE_NAME}/")[1] for f in glob(f"{loc}/**", recursive=True) if os.path.isfile(f)])
print(data_files)

setup(name=PACKAGE_NAME,
      version="22.0.0.dev2",
      description="The frontend of the ISIS Autoreduction service",
      author="ISIS Autoreduction Team",
      url="https://github.com/ISISScientificComputing/autoreduce-frontend/",
      install_requires=[
          "autoreduce_utils==22.0.0.dev3", "autoreduce_db==22.0.0.dev5", "autoreduce_qp==22.0.0.dev3", "Django==3.2.4",
          "django_extensions==3.1.3", "django-user-agents==0.4.0", "djangorestframework==3.12.4"
      ],
      packages=find_packages(),
      package_data={"": data_files},
      entry_points={"console_scripts": ["autoreduce-webapp-manage = autoreduce_frontend.manage:main"]})
